@@ -1,12 +1,15 @@
+from __future__ import annotations
 from abc import ABC, abstractmethod
-from typing import Dict, Union, List, Tuple
+from typing import Dict, Union, List, Tuple, TYPE_CHECKING
 import numpy as np
 import json
 
 from scipy import sparse
 
+if TYPE_CHECKING:
+    from clayrs.content_analyzer.memory_interfaces.memory_interfaces import InformationInterface
+
 from clayrs.content_analyzer.content_representation.representation_container import RepresentationContainer
-from clayrs.content_analyzer.memory_interfaces.memory_interfaces import InformationInterface
 
 
 class FieldRepresentation(ABC):
