@@ -1,12 +1,16 @@
+from __future__ import annotations
 import abc
-from typing import Dict, List, Set, Union
+from typing import Dict, List, Set, Union, TYPE_CHECKING
 
-from clayrs.content_analyzer.ratings_manager.ratings import Interaction, Ratings
+if TYPE_CHECKING:
+    from clayrs.content_analyzer.ratings_manager.ratings import Interaction, Ratings
+    from clayrs.recsys.graphs.graph import UserNode, Node, Graph, BipartiteDiGraph
+    from clayrs.recsys.methodology import Methodology
+
+from clayrs.recsys.graphs.graph import ItemNode
+from clayrs.recsys.methodology import TestRatingsMethodology
 from clayrs.recsys.algorithm import Algorithm
 
-from clayrs.recsys.graphs.graph import UserNode, Node, Graph, ItemNode, BipartiteDiGraph
-from clayrs.recsys.methodology import Methodology, TestRatingsMethodology
-
 
 class GraphBasedAlgorithm(Algorithm):
     """
@@ -55,7 +59,7 @@ class GraphBasedAlgorithm(Algorithm):
     @abc.abstractmethod
     def predict(self, all_users: Set[str], graph: Graph, test_set: Ratings,
                 methodology: Union[Methodology, None] = TestRatingsMethodology(),
-                num_cpus: int = 0) -> List[Interaction]:
+                num_cpus: int = 1) -> List[Interaction]:
         """
         Abstract method that predicts how much a user will like unrated items.
         If the algorithm is not a PredictionScore Algorithm, implement this method like this:
@@ -86,7 +90,7 @@ class GraphBasedAlgorithm(Algorithm):
     @abc.abstractmethod
     def rank(self, all_users: Set[str], graph: Graph, test_set: Ratings,
              recs_number: int = None, methodology: Union[Methodology, None] = TestRatingsMethodology(),
-             num_cpus: int = 0) -> List[Interaction]:
+             num_cpus: int = 1) -> List[Interaction]:
         """
         Rank the top-n recommended items for the user. If the recs_number parameter isn't specified,
         All unrated items for the user will be ranked (or only items in the filter list, if specified).
