@@ -1,11 +1,14 @@
-from typing import List, Set
+from __future__ import annotations
+from typing import List, Set, TYPE_CHECKING
 
-from clayrs.content_analyzer.ratings_manager.ratings import Interaction, Ratings
-from clayrs.recsys.graphs import NXBipartiteGraph
+if TYPE_CHECKING:
+    from clayrs.content_analyzer.ratings_manager.ratings import Interaction, Ratings
+    from clayrs.recsys.graphs import NXBipartiteGraph
+    from clayrs.recsys.methodology import Methodology
 
 from clayrs.recsys.content_based_algorithm.exceptions import NotPredictionAlg
 from clayrs.recsys.graph_based_algorithm.graph_based_algorithm import GraphBasedAlgorithm
-from clayrs.recsys.methodology import Methodology, TestRatingsMethodology
+from clayrs.recsys.methodology import TestRatingsMethodology
 
 
 class PageRank(GraphBasedAlgorithm):
@@ -27,7 +30,7 @@ class PageRank(GraphBasedAlgorithm):
 
     def predict(self, all_users: Set[str], graph: NXBipartiteGraph, test_set: Ratings,
                 methodology: Methodology = TestRatingsMethodology(),
-                num_cpus: int = 0) -> List[Interaction]:
+                num_cpus: int = 1) -> List[Interaction]:
         """
         PageRank is not a Prediction Score Algorithm, so if this method is called,
         a NotPredictionAlg exception is raised
