@@ -5,7 +5,7 @@ import numpy as np
 
 from clayrs.content_analyzer import Ratings
 from clayrs.evaluation.metrics.ranking_metrics import NDCG, Correlation, MRR, NDCGAtK, MRRAtK, MAP, MAPAtK
-from clayrs.recsys import Split
+from clayrs.evaluation.eval_pipeline_modules.metric_evaluator import Split
 
 pred_only_new_items = pd.DataFrame(
     {'user_id': ['u1', 'u1', 'u2', 'u2'],
